@@ -157,7 +157,7 @@ REST::Neo4p::Batch - Mixin for batch processing
  use REST::Neo4p::Batch;
  use List::MoreUtils qw(pairwise);
 
- my @bunch = map { "new_node_$_" } (1.100);
+ my @bunch = map { "new_node_$_" } (1..100);
  my @nodes;
  batch {
   my $idx = REST::Neo4p::Index->new('node','bunch');
@@ -174,12 +174,12 @@ REST::Neo4p::Batch - Mixin for batch processing
 
 =head1 DESCRIPTION
 
-C<REST::Neo4p::Batch> adds some syntactic sugar allowing ordinary
+REST::Neo4p::Batch adds some syntactic sugar allowing ordinary
 REST::Neo4p code to be processed through the Neo4j REST batch API.
 
 =head1 batch {} ($action)
 
-To execute server calls generated by C<REST::Neo4p> code, 
+To execute server calls generated by REST::Neo4p code, 
 wrap the code in a batch block:
 
  batch {
@@ -192,16 +192,19 @@ The C<$action> parameter B<must be> (there is no default) one of
 
 =item * 'keep_objs'
 
-If C<keep_objs> is specified, any nodes, relationships or indexes returned 
-in the server reponse will be created in memory as C<REST::Neo4p> objects.
-This is more time-efficient if the program plans to use the objects subsequently.
+If C<keep_objs> is specified, any nodes, relationships or indexes
+returned in the server reponse will be created in memory as
+REST::Neo4p objects.  This is more time-efficient if the program plans
+to use the objects subsequently.
 
 =item * 'discard_objs'
 
 If C<discard_objs> is specified, Neo4j entities in the server response
-will not be automatically registered as C<REST::Neo4p> objects. Of
+will not be automatically registered as REST::Neo4p objects. Of
 course, these objects can be retrieved from the server through object
-creation and other methods, outside of the batch block. This is more space efficient if the program does not plan to use the objects subsequently: 
+creation and other methods, outside of the batch block. This is more
+space efficient if the program does not plan to use the objects
+subsequently:
 
  #!perl
  # loader...
@@ -210,7 +213,7 @@ creation and other methods, outside of the batch block. This is more space effic
  
  open $f, shift() or die $!;
  batch {
-   while (<>) {
+   while (<$f>) {
     chomp;
     ($name, $value) = split /\t/;
     REST::Neo4p::Node->new({name => $name, value => $value});
@@ -219,10 +222,10 @@ creation and other methods, outside of the batch block. This is more space effic
 
 =back
 
-=head2 Error in batch jobs
+=head2 Errors in batch jobs
 
 C<batch{}()> returns returns an array of
-L<REST::Neo4p::Neo4jException> error objects for each job that returns
+L<REST::Neo4p::Exceptions|REST::Neo4p::Neo4jException> error objects for each job that returns
 a server-generated error. If no errors were encountered, it returns
 undef.
 
@@ -239,13 +242,13 @@ C<$REST::Neo4p::VERBOSE> is set.
 
 =item *
 
-No call to the server is made until the block is executed. There is
-some magic involved, but not all object functionality is available to
-REST::Neo4p entities obtained within the C<batch> block.
+No call to the server is made until after the block is executed. There
+is some magic provided, but not all object functionality is available
+to REST::Neo4p entities obtained within the C<batch> block.
 
 For example, this works:
 
- my $idx = REST::Neo4p::Index->new('pals_of_bob');
+ my $idx = REST::Neo4p::Index->new('node' => 'pals_of_bob');
  my $name = 'fred'
  batch {
   my $node = REST::Neo4p::Node->new({name => $name});
@@ -254,7 +257,7 @@ For example, this works:
 
 but this does not:
 
- my $idx = REST::Neo4p::Index->new('pals_of_bob');
+ my $idx = REST::Neo4p::Index->new('node' => 'pals_of_bob');
  my $name = 'fred'
  batch {
   my $node = REST::Neo4p::Node->new({name => $name});
